@@ -14,11 +14,13 @@
 handler_newline <- function(symbol = "\n", file = stderr(), intrusiveness = getOption("progressr.intrusiveness.debug", 0), target = "terminal", ...) {
   reporter <- local({
     list(
+      hide     = function(...) NULL,
+      unhide   = function(...) NULL,
       initiate = function(...) cat(file = file, symbol),
       update   = function(...) cat(file = file, symbol),
       finish   = function(...) cat(file = file, symbol)
     )
   })
   
-  make_progression_handler("newline", reporter, intrusiveness = intrusiveness, ...)
+  make_progression_handler("newline", reporter, intrusiveness = intrusiveness, target = target, ...)
 }
